FugueCodec<T> constructor
const
FugueCodec<T> (
- Codec<
T> element
Wraps an element codec for the value type T.
Implementation
const FugueCodec(this.element);
Wraps an element codec for the value type T.
const FugueCodec(this.element);