FugueOp<T> class sealed

One operation in a Fugue.applyOps batch.

Implementers

Constructors

FugueOp.insert(int at, T value)
Insert value at visible index at.
const
factory
FugueOp.removeAt(int at)
Remove the live element at visible index at.
const
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited