FugueRemoveAt<T> class final

A remove op — see FugueOp.removeAt.

Inheritance

Constructors

FugueRemoveAt(int at)
Creates a remove at at.
const

Properties

at int
Target visible index.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited